@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.clouddms_v1.services.data_migration_service import pagers
@@ -180,17 +182,17 @@ class DataMigrationServiceAsyncClient:
 
     async def list_migration_jobs(
         self,
-        request: clouddms.ListMigrationJobsRequest = None,
+        request: Union[clouddms.ListMigrationJobsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMigrationJobsAsyncPager:
         r"""Lists migration jobs in a given project and location.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.ListMigrationJobsRequest`):
+            request (Union[google.cloud.clouddms_v1.types.ListMigrationJobsRequest, dict]):
                 The request object. Retrieve a list of all migration
                 jobs in a given project and location.
             parent (:class:`str`):
@@ -260,17 +262,17 @@ class DataMigrationServiceAsyncClient:
 
     async def get_migration_job(
         self,
-        request: clouddms.GetMigrationJobRequest = None,
+        request: Union[clouddms.GetMigrationJobRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms_resources.MigrationJob:
         r"""Gets details of a single migration job.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.GetMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.GetMigrationJobRequest, dict]):
                 The request object. Request message for
                 'GetMigrationJob' request.
             name (:class:`str`):
@@ -331,12 +333,12 @@ class DataMigrationServiceAsyncClient:
 
     async def create_migration_job(
         self,
-        request: clouddms.CreateMigrationJobRequest = None,
+        request: Union[clouddms.CreateMigrationJobRequest, dict] = None,
         *,
         parent: str = None,
         migration_job: clouddms_resources.MigrationJob = None,
         migration_job_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -344,7 +346,7 @@ class DataMigrationServiceAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.CreateMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.CreateMigrationJobRequest, dict]):
                 The request object. Request message to create a new
                 Database Migration Service migration job in the
                 specified project and region.
@@ -437,18 +439,18 @@ class DataMigrationServiceAsyncClient:
 
     async def update_migration_job(
         self,
-        request: clouddms.UpdateMigrationJobRequest = None,
+        request: Union[clouddms.UpdateMigrationJobRequest, dict] = None,
         *,
         migration_job: clouddms_resources.MigrationJob = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single migration job.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.UpdateMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.UpdateMigrationJobRequest, dict]):
                 The request object. Request message for
                 'UpdateMigrationJob' request.
             migration_job (:class:`google.cloud.clouddms_v1.types.MigrationJob`):
@@ -534,17 +536,17 @@ class DataMigrationServiceAsyncClient:
 
     async def delete_migration_job(
         self,
-        request: clouddms.DeleteMigrationJobRequest = None,
+        request: Union[clouddms.DeleteMigrationJobRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single migration job.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.DeleteMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.DeleteMigrationJobRequest, dict]):
                 The request object. Request message for
                 'DeleteMigrationJob' request.
             name (:class:`str`):
@@ -626,16 +628,16 @@ class DataMigrationServiceAsyncClient:
 
     async def start_migration_job(
         self,
-        request: clouddms.StartMigrationJobRequest = None,
+        request: Union[clouddms.StartMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Start an already created migration job.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.StartMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.StartMigrationJobRequest, dict]):
                 The request object. Request message for
                 'StartMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -687,16 +689,16 @@ class DataMigrationServiceAsyncClient:
 
     async def stop_migration_job(
         self,
-        request: clouddms.StopMigrationJobRequest = None,
+        request: Union[clouddms.StopMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Stops a running migration job.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.StopMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.StopMigrationJobRequest, dict]):
                 The request object. Request message for
                 'StopMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -748,9 +750,9 @@ class DataMigrationServiceAsyncClient:
 
     async def resume_migration_job(
         self,
-        request: clouddms.ResumeMigrationJobRequest = None,
+        request: Union[clouddms.ResumeMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -758,7 +760,7 @@ class DataMigrationServiceAsyncClient:
         is resumable (was stopped during CDC phase).
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.ResumeMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.ResumeMigrationJobRequest, dict]):
                 The request object. Request message for
                 'ResumeMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -810,9 +812,9 @@ class DataMigrationServiceAsyncClient:
 
     async def promote_migration_job(
         self,
-        request: clouddms.PromoteMigrationJobRequest = None,
+        request: Union[clouddms.PromoteMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -821,7 +823,7 @@ class DataMigrationServiceAsyncClient:
         standalone database.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.PromoteMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.PromoteMigrationJobRequest, dict]):
                 The request object. Request message for
                 'PromoteMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -873,9 +875,9 @@ class DataMigrationServiceAsyncClient:
 
     async def verify_migration_job(
         self,
-        request: clouddms.VerifyMigrationJobRequest = None,
+        request: Union[clouddms.VerifyMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -884,7 +886,7 @@ class DataMigrationServiceAsyncClient:
         prerequisites are met.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.VerifyMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.VerifyMigrationJobRequest, dict]):
                 The request object. Request message for
                 'VerifyMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -936,9 +938,9 @@ class DataMigrationServiceAsyncClient:
 
     async def restart_migration_job(
         self,
-        request: clouddms.RestartMigrationJobRequest = None,
+        request: Union[clouddms.RestartMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -947,7 +949,7 @@ class DataMigrationServiceAsyncClient:
         starting the migration process from scratch.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.RestartMigrationJobRequest`):
+            request (Union[google.cloud.clouddms_v1.types.RestartMigrationJobRequest, dict]):
                 The request object. Request message for
                 'RestartMigrationJob' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -999,9 +1001,9 @@ class DataMigrationServiceAsyncClient:
 
     async def generate_ssh_script(
         self,
-        request: clouddms.GenerateSshScriptRequest = None,
+        request: Union[clouddms.GenerateSshScriptRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms.SshScript:
@@ -1009,7 +1011,7 @@ class DataMigrationServiceAsyncClient:
         reverse SSH connectivity.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.GenerateSshScriptRequest`):
+            request (Union[google.cloud.clouddms_v1.types.GenerateSshScriptRequest, dict]):
                 The request object. Request message for
                 'GenerateSshScript' request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1051,10 +1053,10 @@ class DataMigrationServiceAsyncClient:
 
     async def list_connection_profiles(
         self,
-        request: clouddms.ListConnectionProfilesRequest = None,
+        request: Union[clouddms.ListConnectionProfilesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListConnectionProfilesAsyncPager:
@@ -1062,7 +1064,7 @@ class DataMigrationServiceAsyncClient:
         project and location.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.ListConnectionProfilesRequest`):
+            request (Union[google.cloud.clouddms_v1.types.ListConnectionProfilesRequest, dict]):
                 The request object. Request message for
                 'ListConnectionProfiles' request.
             parent (:class:`str`):
@@ -1132,17 +1134,17 @@ class DataMigrationServiceAsyncClient:
 
     async def get_connection_profile(
         self,
-        request: clouddms.GetConnectionProfileRequest = None,
+        request: Union[clouddms.GetConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms_resources.ConnectionProfile:
         r"""Gets details of a single connection profile.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.GetConnectionProfileRequest`):
+            request (Union[google.cloud.clouddms_v1.types.GetConnectionProfileRequest, dict]):
                 The request object. Request message for
                 'GetConnectionProfile' request.
             name (:class:`str`):
@@ -1201,12 +1203,12 @@ class DataMigrationServiceAsyncClient:
 
     async def create_connection_profile(
         self,
-        request: clouddms.CreateConnectionProfileRequest = None,
+        request: Union[clouddms.CreateConnectionProfileRequest, dict] = None,
         *,
         parent: str = None,
         connection_profile: clouddms_resources.ConnectionProfile = None,
         connection_profile_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1214,7 +1216,7 @@ class DataMigrationServiceAsyncClient:
         and location.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.CreateConnectionProfileRequest`):
+            request (Union[google.cloud.clouddms_v1.types.CreateConnectionProfileRequest, dict]):
                 The request object. Request message for
                 'CreateConnectionProfile' request.
             parent (:class:`str`):
@@ -1304,11 +1306,11 @@ class DataMigrationServiceAsyncClient:
 
     async def update_connection_profile(
         self,
-        request: clouddms.UpdateConnectionProfileRequest = None,
+        request: Union[clouddms.UpdateConnectionProfileRequest, dict] = None,
         *,
         connection_profile: clouddms_resources.ConnectionProfile = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1316,7 +1318,7 @@ class DataMigrationServiceAsyncClient:
         profile.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.UpdateConnectionProfileRequest`):
+            request (Union[google.cloud.clouddms_v1.types.UpdateConnectionProfileRequest, dict]):
                 The request object. Request message for
                 'UpdateConnectionProfile' request.
             connection_profile (:class:`google.cloud.clouddms_v1.types.ConnectionProfile`):
@@ -1401,10 +1403,10 @@ class DataMigrationServiceAsyncClient:
 
     async def delete_connection_profile(
         self,
-        request: clouddms.DeleteConnectionProfileRequest = None,
+        request: Union[clouddms.DeleteConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1414,7 +1416,7 @@ class DataMigrationServiceAsyncClient:
         jobs.
 
         Args:
-            request (:class:`google.cloud.clouddms_v1.types.DeleteConnectionProfileRequest`):
+            request (Union[google.cloud.clouddms_v1.types.DeleteConnectionProfileRequest, dict]):
                 The request object. Request message for
                 'DeleteConnectionProfile' request.
             name (:class:`str`):
