@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.clouddms_v1.services.data_migration_service import pagers
@@ -380,7 +382,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.ListMigrationJobsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMigrationJobsPager:
@@ -460,7 +462,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.GetMigrationJobRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms_resources.MigrationJob:
@@ -533,7 +535,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         parent: str = None,
         migration_job: clouddms_resources.MigrationJob = None,
         migration_job_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -638,7 +640,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         *,
         migration_job: clouddms_resources.MigrationJob = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -734,7 +736,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.DeleteMigrationJobRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -825,7 +827,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.StartMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -887,7 +889,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.StopMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -949,7 +951,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.ResumeMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1012,7 +1014,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.PromoteMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1076,7 +1078,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.VerifyMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1140,7 +1142,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.RestartMigrationJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1204,7 +1206,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         self,
         request: Union[clouddms.GenerateSshScriptRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms.SshScript:
@@ -1258,7 +1260,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.ListConnectionProfilesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListConnectionProfilesPager:
@@ -1339,7 +1341,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.GetConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> clouddms_resources.ConnectionProfile:
@@ -1410,7 +1412,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         parent: str = None,
         connection_profile: clouddms_resources.ConnectionProfile = None,
         connection_profile_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1514,7 +1516,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         *,
         connection_profile: clouddms_resources.ConnectionProfile = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1612,7 +1614,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         request: Union[clouddms.DeleteConnectionProfileRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
